@@ -2,11 +2,11 @@ package File::Spotlight;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
-use Mac::Tie::PList;
 use String::ShellQuote;
+use Scalar::Util qw(blessed);
 
 sub new {
     my $class = shift;
@@ -16,10 +16,11 @@ sub new {
 sub list {
     my($self, $file) = @_;
 
-    my $plist = Mac::Tie::PList->new_from_file($file)
+    my $plist = $self->parse_plist($file)
         or croak "Can't open savedSearch file $file";
 
     my $query = $plist->{RawQuery};
+       $query = _get_value($query) if blessed $query;
     my @search_paths = map $self->_transform_path($_), @{ $plist->{SearchCriteria}{FXScopeArrayOfPaths} || [] };
 
     my @files;
@@ -30,6 +31,17 @@ sub list {
     return @files;
 }
 
+sub parse_plist {
+    my($self, $file) = @_;
+
+    if (eval { require Mac::Tie::PList }) {
+        return Mac::Tie::PList->new_from_file($file);
+    } else {
+        require Mac::PropertyList;
+        Mac::PropertyList::parse_plist_file($file);
+    }
+}
+
 sub _run_mdfind {
     my($self, $path, $query) = @_;
 
@@ -46,6 +58,7 @@ sub _run_mdfind {
 
 sub _transform_path {
     my($self, $path) = @_;
+    $path = _get_value($path) if blessed $path;
 
     return $ENV{HOME} if $path eq 'kMDQueryScopeHome';
     return "/"        if $path eq 'kMDQueryScopeComputer';
@@ -53,6 +66,19 @@ sub _transform_path {
     return $path;
 }
 
+my %decode = (amp => '&', quot => '"', lt => '<', gt => '>');
+
+sub _get_value {
+    my $string = shift;
+
+    # Mac::PropertyList doesn't decode XML escapes
+    $string = $string->value;
+    $string =~ s/&(amp|quot|lt|gt);/$decode{$1}/eg;
+
+    return $string;
+}
+
+
 1;
 __END__
 
